`piel` - Photonic and Integrated ELectronic tools
=================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   examples
   sections/environment/index
   sections/integration/index
   sections/codesign/index
   modules
   contributing
   authors
   about/index

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
